@@ -330,6 +330,7 @@ def run(
     dataset_cloud_names: Optional[List[str]]=None,
     model_cloud_names: Optional[List[str]]=None,
     project_name: Optional[str]=None,
+    task_name: Optional[str]=None,
     image_name: Optional[str]="QUICKSTART",
     quota_group_request: Optional[Dict[str, int]]=None,
 ) -> Optional[TrainTask]:
@@ -380,6 +381,7 @@ def upload_and_run(
     dataset_cloud_names: Optional[List[str]]=None,
     model_cloud_names: Optional[List[str]]=None,
     project_name: Optional[str]=None,
+    task_name: Optional[str]=None,
     image_name: Optional[str]="QUICKSTART",
     quota_group_request: Optional[Dict[str, int]]=None,
 ) -> TrainTask:
@@ -441,6 +443,7 @@ def quick_train(algorithm_id: Optional[str]=None,
                 resource_request: Optional[List[Dict[str, Dict[str, int]]]]=None,
                 quota_group_name: Optional[str]=None,
                 quota_group_request: Optional[Dict[str, int]]=None,
+                task_name: Optional[str]=None,
                 task_description: Optional[str]=None,
                 num_nodes: Optional[int]=1,
                 nproc_per_node: Optional[int]=1):
@@ -676,6 +679,9 @@ def quick_train(algorithm_id: Optional[str]=None,
     quota_group_request : :obj:`dict`, optional
         训练所需计算资源组中资源数量。
         若 :obj:`quota_group_name` 和 :obj:`quota_group_request` 有其一未填，则使用Anylearn后端的 :obj:`default` 资源组中的默认资源套餐。
+    task_name : :obj:`str`, optional
+        训练任务名称。
+        若值为非空，则由SDK自动生成8位随机字符串作为训练任务名称。
     task_description : :obj:`str`, optional
         训练任务详细描述。
         若值为非空，
@@ -872,7 +878,7 @@ def quick_train(algorithm_id: Optional[str]=None,
             project = _get_or_create_project()
 
     # Train task
-    train_task_name = generate_random_name()
+    train_task_name = task_name or generate_random_name()
     _hyperparams = hyperparams or algorithm_hyperparams
     _hyperparams_prefix = hyperparams_prefix or algorithm_hyperparams_prefix
     _hyperparams_delimeter = hyperparams_delimeter or algorithm_hyperparams_delimeter
