@@ -1,9 +1,10 @@
 import responses
 from requests.exceptions import RequestException
 
-from anylearn.interfaces.project import Project, ProjectVisibility
+from anylearn.interfaces.project import Project
 from anylearn.utils.errors import AnyLearnException, AnyLearnMissingParamException
 from tests.base_test_case import BaseTestCase
+from tests.config import test_username
 
 class TestProject(BaseTestCase):
     @responses.activate
@@ -52,11 +53,9 @@ class TestProject(BaseTestCase):
                           'id': "PROJ001",
                           'name': "TestProj1",
                           'description': "test",
-                          'visibility': ProjectVisibility.PUBLIC,
                           'create_time': "2020-03-01 00:00",
                           'update_time': "2020-03-01 00:00",
                           'creator_id': "USER001",
-                          'owner': ["USER001"],
                           'datasets': ["DSET001", "DSET002"]
                       }],
                       status=200)
@@ -64,12 +63,9 @@ class TestProject(BaseTestCase):
         project.get_detail()
         self.assertEqual(project.name, "TestProj1")
         self.assertEqual(project.description, "test")
-        self.assertEqual(project.visibility, ProjectVisibility.PUBLIC)
         self.assertEqual(project.create_time, "2020-03-01 00:00")
         self.assertEqual(project.update_time, "2020-03-01 00:00")
         self.assertEqual(project.creator_id, "USER001")
-        self.assertIsInstance(project.owner, list)
-        self.assertEqual(project.owner[0], "USER001")
         self.assertIsInstance(project.datasets, list)
         if isinstance(project.datasets, list):
             self.assertEqual(len(project.datasets), 2)
@@ -83,11 +79,9 @@ class TestProject(BaseTestCase):
                           'id': "PROJ002",
                           'name': "TestProj2",
                           'description': "test",
-                          'visibility': ProjectVisibility.PUBLIC,
                           'create_time': "2020-03-02 00:00",
                           'update_time': "2020-03-02 00:00",
                           'creator_id': "USER001",
-                          'owner': ["USER001"],
                           'datasets': ["DSET001", "DSET002"]
                       }],
                       status=200)
@@ -95,18 +89,46 @@ class TestProject(BaseTestCase):
         project.get_detail()
         self.assertEqual(project.name, "TestProj2")
         self.assertEqual(project.description, "test")
-        self.assertEqual(project.visibility, ProjectVisibility.PUBLIC)
         self.assertEqual(project.create_time, "2020-03-02 00:00")
         self.assertEqual(project.update_time, "2020-03-02 00:00")
         self.assertEqual(project.creator_id, "USER001")
-        self.assertIsInstance(project.owner, list)
-        self.assertEqual(project.owner[0], "USER001")
         self.assertIsInstance(project.datasets, list)
         if isinstance(project.datasets,list):
             self.assertEqual(len(project.datasets), 2)
         self.assertEqual(project.datasets[0], "DSET001")
         self.assertEqual(project.datasets[1], "DSET002")
 
+    @responses.activate
+    def test_get_project_detail_ok_401_auto_relogin(self):
+        responses.add(responses.GET, url=self._url("project/query?id=PROJ401"),
+                      match_querystring=True, status=401)
+        responses.add(responses.GET, url=self._url("user/refresh_token"),
+                      json={
+                          'id': "USER001",
+                          'refresh_token': "TEST_REFRESH_TOKEN",
+                          'token': "TEST_TOKEN_REFRESHED",
+                          'username': test_username
+                      },
+                      status=200)
+        responses.add(responses.GET, url=self._url("project/query?id=PROJ401"),
+                      match_querystring=True, json=[{
+                          'id': "PROJ401",
+                          'name': "TestProj401",
+                          'description': "test",
+                          'create_time': "2020-03-02 00:00",
+                          'update_time': "2020-03-02 00:00",
+                          'creator_id': "USER001",
+                          'datasets': ["DSET001", "DSET002"]
+                      }],
+                      status=200)
+        project = Project(id="PROJ401")
+        project.get_detail()
+        self.assertEqual(project.name, "TestProj401")
+        self.assertEqual(project.description, "test")
+        self.assertEqual(project.create_time, "2020-03-02 00:00")
+        self.assertEqual(project.update_time, "2020-03-02 00:00")
+        self.assertEqual(project.creator_id, "USER001")
+
     @responses.activate
     def test_get_project_detail_ko_403(self):
         responses.add(responses.GET, url=self._url("project/query?id=PROJ403"),
